# Version of java
%define javaver 1.8.0

# Alternatives priority
%define priority 18000

%define javadir     %{_jvmdir}/java-%{javaver}-openjdk
%define jredir      %{_jvmdir}/jre-%{javaver}-openjdk
%define javaplugin  libjavaplugin.so.%{_arch}

%define binsuffix      .itweb

%define preffered_java  java-%{javaver}-openjdk

Name:		icedtea-web
Version:	1.7.2
Release:	%mkrel 4
Summary:	Additional Java components for OpenJDK - Java browser plug-in and Web Start implementation

Group:      Networking/WWW
License:    LGPLv2+ and GPLv2 with exceptions
URL:        http://icedtea.classpath.org/wiki/IcedTea-Web
Source0:    http://icedtea.classpath.org/download/source/%{name}-%{version}.tar.gz
Patch0:     icedtea-web-1.7.1-pthread.patch
Patch1:     issue1.patch
Patch2:     issue2.patch
Patch3:     issue3.patch
Patch4:     PreventiveleQueue.patch
Patch5:     icedtea-web-1.7.2-mga-remove-sh-suffix.patch

BuildRequires:  javapackages-tools
#for deprecated add_maven_depmap, see https://www.spinics.net/lists/fedora-devel/msg233211.html
BuildRequires:  javapackages-local
BuildRequires:  %{preffered_java}-devel
BuildRequires:  desktop-file-utils
BuildRequires:  glib2-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  clang
BuildRequires:  junit
BuildRequires:  hamcrest
BuildRequires:  appstream-util
BuildRequires:  zip
# new in 1.5 to have  clean up for malformed XMLs
BuildRequires:  tagsoup
# rhino is used as JS evaluator in testtime
BuildRequires:  rhino
BuildRequires:  pkgconfig(mozilla-plugin)
BuildRequires:  pkgconfig(x11)

# For functionality and the OpenJDK dirs
Requires:       %{preffered_java}
Requires:       javapackages-tools
Recommends:     bash-completion
#maven fragments
Requires(post):      javapackages-tools
Requires(postun):      javapackages-tools
# For the mozilla plugin dir
Requires:       mozilla-filesystem

# When itw builds against it, it have to be also in runtime
Requires:       tagsoup
# rhino is used as JS evaluator in runtime
Requires:       rhino

# Post requires alternatives to install plugin alternative.
Requires(post):   update-alternatives

# Postun requires alternatives to uninstall plugin alternative.
Requires(postun): update-alternatives

# Standard JPackage plugin provides.
Provides: java-plugin = 1:%{javaver}
Provides: javaws      = 1:%{javaver}

Provides:   %{preffered_java}-plugin =  1:%{version}

%description
The IcedTea-Web project provides a Java web browser plugin, an implementation
of Java Web Start (originally based on the Netx project) and a settings tool to
manage deployment settings for the aforementioned plugin and Web Start
implementations. 

%package javadoc
Summary:    API documentation for IcedTea-Web
Group:      Documentation
Requires:   %{name} >= %{version}-%{release}
BuildArch:  noarch

%description javadoc
This package contains Javadocs for the IcedTea-Web project.


%package devel
Summary:    pure sources for debugging IcedTea-Web
Group:      Development/Java
Requires:   %{name} >= %{version}-%{release}
BuildArch:  noarch

%description devel
This package contains ziped sources of the IcedTea-Web project.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -vfi
CXXFLAGS="$RPM_OPT_FLAGS $RPM_LD_FLAGS" \
%configure2_5x \
    --with-pkgversion=%{_real_vendor}-%{release}-%{_arch} \
    --docdir=%{_datadir}/javadoc/%{name} \
    --with-jdk-home=%{javadir} \
    --with-jre-home=%{jredir} \
    --libdir=%{_libdir} \
    --program-suffix=%{binsuffix} \
    --prefix=%{_prefix}
%make_build

%install
%make_install

# icedteaweb-completion is currently not handled by make nor make install
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/
mv completion/policyeditor.bash $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/
mv completion/javaws.bash $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/
mv completion/itweb-settings.bash $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/

# Move javaws man page to a more specific name
mv $RPM_BUILD_ROOT/%{_mandir}/man1/javaws.1 $RPM_BUILD_ROOT/%{_mandir}/man1/javaws.itweb.1

# Install desktop files.
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/{applications,pixmaps}
desktop-file-install --vendor ''\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications javaws.desktop
desktop-file-install --vendor ''\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications itweb-settings.desktop
desktop-file-install --vendor ''\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications policyeditor.desktop

# install MetaInfo file for firefox
DESTDIR=%{buildroot} appstream-util install metadata/%{name}.metainfo.xml
# install MetaInfo file for javaws
DESTDIR=%{buildroot} appstream-util install metadata/%{name}-javaws.appdata.xml

# maven fragments generation
mkdir -p $RPM_BUILD_ROOT%{_javadir}
pushd $RPM_BUILD_ROOT%{_javadir}
ln -s ../%{name}/netx.jar %{name}.jar
ln -s ../%{name}/plugin.jar %{name}-plugin.jar
popd
mkdir -p $RPM_BUILD_ROOT/%{_mavenpomdir}
cp  metadata/%{name}.pom  $RPM_BUILD_ROOT/%{_mavenpomdir}/%{name}.pom
cp metadata/%{name}-plugin.pom  $RPM_BUILD_ROOT/%{_mavenpomdir}/%{name}-plugin.pom

%add_maven_depmap %{name}.pom %{name}.jar
%add_maven_depmap %{name}-plugin.pom %{name}-plugin.jar

cp  netx.build/lib/src.zip  $RPM_BUILD_ROOT%{_datadir}/%{name}/netx.src.zip
cp liveconnect/lib/src.zip  $RPM_BUILD_ROOT%{_datadir}/%{name}/plugin.src.zip

%find_lang %{name} --all-name --with-man

rm -rf $RPM_BUILD_ROOT%{_datadir}/bash-completion/

%check
make check
appstream-util validate $RPM_BUILD_ROOT/%{_datadir}/appdata/*.xml || :

%post
alternatives \
  --install %{_libdir}/mozilla/plugins/libjavaplugin.so %{javaplugin} \
  %{_libdir}/IcedTeaPlugin.so %{priority}

alternatives \
  --install %{_bindir}/javaws				javaws.%{_arch}		%{_prefix}/bin/javaws%{binsuffix} %{priority}  --family %{preffered_java}.%{_arch} \
  --slave   %{_bindir}/itweb-settings			itweb-settings		%{_prefix}/bin/itweb-settings%{binsuffix} \
  --slave   %{_bindir}/policyeditor			policyeditor		%{_prefix}/bin/policyeditor%{binsuffix} \
  --slave   %{_bindir}/ControlPanel			ControlPanel		%{_prefix}/bin/itweb-settings%{binsuffix} \
  --slave   %{_mandir}/man1/javaws.1.xz			javaws.1.xz		%{_mandir}/man1/javaws%{binsuffix}.1.xz \
  --slave   %{_mandir}/man1/ControlPanel.1.xz		ControlPanel.1.xz	%{_mandir}/man1/itweb-settings.1.xz

exit 0

%postun
if [ $1 -eq 0 ]; then
  alternatives --remove %{javaplugin} \
    %{_libdir}/IcedTeaPlugin.so
  alternatives --remove javaws.%{_arch} \
    %{_prefix}/bin/javaws%{binsuffix}
fi
exit 0

%files -f .mfiles -f %{name}.lang
%{_sysconfdir}/bash_completion.d/*
%{_prefix}/bin/*
%{_libdir}/IcedTeaPlugin.so
%{_datadir}/applications/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.jar
%{_datadir}/%{name}/*.png
%{_datadir}/man/man1/*
%{_datadir}/pixmaps/*
%{_datadir}/appdata/*.xml
%doc NEWS README
%license COPYING

%files javadoc
%{_datadir}/javadoc/%{name}
%license COPYING

%files devel
%{_datadir}/%{name}/*.zip
%license COPYING



%changelog
* Fri Aug 30 2019 ns80 <ns80> 1.7.2-4.mga6
+ Revision: 1435413
- new version 1.7.2 for CVE-2019-1018[125] (mga#25228)

* Tue Mar 08 2016 luigiwalser <luigiwalser> 1.6.2-1.mga6
+ Revision: 987251
- 1.6.2
- remove upstream patches
- install appdata files

* Mon Feb 15 2016 umeabot <umeabot> 1.6.1-3.mga6
+ Revision: 960665
- Mageia 6 Mass Rebuild

* Fri Oct 23 2015 luigiwalser <luigiwalser> 1.6.1-2.mga6
+ Revision: 894630
- add three upstream bugfix patches (from fedora)

* Tue Sep 15 2015 luigiwalser <luigiwalser> 1.6.1-1.mga6
+ Revision: 879678
- BR zip is still needed
- 1.6.1
- BR hamcrest and not zip
- install bash_completion file

* Mon Sep 14 2015 luigiwalser <luigiwalser> 1.5.3-1.mga6
+ Revision: 879497
- 1.5.3 (fixes CVE-2015-5234 and CVE-2015-5235)

* Tue Dec 02 2014 luigiwalser <luigiwalser> 1.5.2-1.mga5
+ Revision: 800291
- 1.5.2

* Wed Oct 15 2014 umeabot <umeabot> 1.5.1-3.mga5
+ Revision: 742049
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.1-2.mga5
+ Revision: 680444
- Mageia 5 Mass Rebuild

* Sat Aug 16 2014 luigiwalser <luigiwalser> 1.5.1-1.mga5
+ Revision: 663995
- 1.5.1
- remove upstreamed patches

* Tue Aug 05 2014 dmorgan <dmorgan> 1.5-1.mga5
+ Revision: 659866
- New version
  Build against openjdk8

* Fri Feb 07 2014 luigiwalser <luigiwalser> 1.4.2-1.mga5
+ Revision: 585370
- 1.4.2

* Fri Jan 10 2014 pterjan <pterjan> 1.4.1-3.mga4
+ Revision: 566100
- Add missing BuildRequires
- Fix Buildequires

* Sat Oct 19 2013 umeabot <umeabot> 1.4.1-2.mga4
+ Revision: 534962
- Mageia 4 Mass Rebuild

* Mon Sep 16 2013 oden <oden> 1.4.1-1.mga4
+ Revision: 480327
- 1.4.1 (fixes CVE-2013-4349)

* Sun Jun 23 2013 luigiwalser <luigiwalser> 1.4-1.mga4
+ Revision: 446041
- 1.4

* Sun Jun 23 2013 luigiwalser <luigiwalser> 1.3.2-2.mga4
+ Revision: 446036
- adapted to latest openjdk changes (from fedora)
- added build requires for autoconf and automake
- add patch from fedora with fix for new openjdk

* Wed Apr 17 2013 luigiwalser <luigiwalser> 1.3.2-1.mga3
+ Revision: 410342
- 1.3.2 (fixes CVE-2013-1926 and CVE-2013-1927)

* Sat Jan 12 2013 umeabot <umeabot> 1.3.1-2.mga3
+ Revision: 354169
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 08 2012 luigiwalser <luigiwalser> 1.3.1-1.mga3
+ Revision: 316479
- 1.3.1 (fixes CVE-2012-4540)

* Fri Sep 07 2012 dmorgan <dmorgan> 1.3-1.mga3
+ Revision: 289285
- New version 1.3

* Wed Aug 01 2012 luigiwalser <luigiwalser> 1.2.1-1.mga3
+ Revision: 277710
- 1.2.1 (fixes CVE-2012-3422 and CVE-2012-3423)

* Mon May 28 2012 dmorgan <dmorgan> 1.2-5.mga3
+ Revision: 248637
- Rebuild against java7

* Wed May 16 2012 dmorgan <dmorgan> 1.2-4.mga2
+ Revision: 235776
- Allow to build on arm as well
- Fix Requires(post) ( mga #5917)

* Wed May 16 2012 dmorgan <dmorgan> 1.2-3.mga2
+ Revision: 235770
- Requires mozilla-filesystem for update-alternatives to work

* Thu Apr 19 2012 dmorgan <dmorgan> 1.2-2.mga2
+ Revision: 231733
- Fix dandling links ( mga #4631)

* Tue Mar 20 2012 dmorgan <dmorgan> 1.2-1.mga2
+ Revision: 225136
- New version 1.2

* Sat Dec 17 2011 gil <gil> 1.1.4-1.mga2
+ Revision: 183243
- update to 1.1.4

* Tue Oct 18 2011 dmorgan <dmorgan> 1.1.3-1.mga2
+ Revision: 156434
- Do not own std dirs
- New version 1.1.3
+ gil <gil>
- New version

* Tue Sep 20 2011 fwang <fwang> 1.0.4-1.mga2
+ Revision: 145970
- fix group
- fix bindir
- fix linkage
+ gil <gil>
- update to 1.0.4

* Thu Jun 16 2011 dmorgan <dmorgan> 1.0.3-1.mga2
+ Revision: 108216
- New version 1.0.3

* Mon Apr 11 2011 tmb <tmb> 1.0.2-5.mga1
+ Revision: 83483
- fix ExclusiveArch so i586 gets built

* Mon Apr 11 2011 tmb <tmb> 1.0.2-4.mga1
+ Revision: 83472
- rebuild for missing package on i586

* Sat Apr 09 2011 dmorgan <dmorgan> 1.0.2-3.mga1
+ Revision: 82529
- Better obsoletes

* Sat Apr 09 2011 dmorgan <dmorgan> 1.0.2-2.mga1
+ Revision: 82525
- Fix openjdk version for the obsolete/provides
  Fix Groups
  Fix layout

* Sat Apr 09 2011 ahmad <ahmad> 1.0.2-1.mga1
+ Revision: 82490
- adapt the spec to Mageia
- add BR zip
- imported package icedtea-web


* Mon Apr 04 2011 Deepak Bhole <dbhole@redhat.com> 1.0.2-2
- Fixed incorrect macro value for min_openjdk_version
- Use posttrans instead of post, so that upgrade from old plugin works

* Mon Apr 04 2011 Deepak Bhole <dbhole@redhat.com> 1.0.2-1
- Initial build
